@@ -57,6 +57,23 @@ namespace zypp
       }
     }
 
+  std::exception_ptr do_ZYPP_FWD_EXCPT_PTR( const std::exception_ptr & excpt_r, const CodeLocation & where_r )
+  {
+    try {
+      std::rethrow_exception( excpt_r );
+    } catch ( zypp::Exception &e ) {
+      e.relocate( where_r );
+      Exception::log( e, where_r, "RETHROW (FWD) EXCPTR:   " );
+      return std::current_exception();
+    } catch ( const std::exception & e ) {
+      Exception::log( typeid(e).name(), where_r, "RETHROW (FWD) EXCPTR:   " );
+      return std::current_exception();
+    } catch (...) {
+      Exception::log( "Unknown Exception", where_r, "RETHROW (FWD) EXCPTR:   " );
+      return std::current_exception();
+    }
+  }
+
     /////////////////////////////////////////////////////////////////
   } // namespace exception_detail
   ///////////////////////////////////////////////////////////////////
