@@ -78,12 +78,12 @@ namespace zyppng {
      * Adds a new object to the child list, the object
      * will keep a reference for its entire lifetime or until the object is removed
      */
-    void addChild ( Base::Ptr child );
+    void addChild ( const Base::Ptr& child );
 
     /*!
      * Removes a child object from the internal child list
      */
-    void removeChild (Ptr child );
+    void removeChild (const Ptr& child );
 
     /*!
      * Returns all child objects of this object
@@ -136,7 +136,7 @@ namespace zyppng {
     }
 
     /*!
-     * Preferred way to connect a signal to a slow, this will automatically take care of tracking the target object in the connection
+     * Preferred way to connect a signal to a slot, this will automatically take care of tracking the target object in the connection
      */
     template< typename SenderFunc, typename ReceiverFunc >
     static auto connect ( typename internal::MemberFunction<SenderFunc>::ClassType &s, SenderFunc &&sFun, typename internal::MemberFunction<ReceiverFunc>::ClassType &recv, ReceiverFunc &&rFunc ) {
